@@ -71,10 +71,14 @@ class SetMixin(object):
         Because dynamodb doesn't store empty attributes,
         empty sets return None
         """
-        if value and len(value):
-            return [json.dumps(val) for val in sorted(value)]
-        else:
-            return None
+        if value is not None:
+            try:
+                iter(value)
+            except TypeError:
+                value = [value]
+            if len(value):
+                return [json.dumps(val) for val in sorted(value)]
+        return None
 
     def deserialize(self, value):
         """
